summaryrefslogtreecommitdiffstats
path: root/src/viewmpeg2.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/viewmpeg2.cpp')
-rw-r--r--src/viewmpeg2.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/viewmpeg2.cpp b/src/viewmpeg2.cpp
index ae8c0f7..2313976 100644
--- a/src/viewmpeg2.cpp
+++ b/src/viewmpeg2.cpp
@@ -125,11 +125,11 @@ static const unsigned char img2_viewmpeg2[] = {
/*
* Constructs a ViewMPEG2 as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-ViewMPEG2::ViewMPEG2( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+ViewMPEG2::ViewMPEG2( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
TQImage img;
img.loadFromData( img0_viewmpeg2, sizeof( img0_viewmpeg2 ), "PNG" );
@@ -125,11 +125,11 @@ static const unsigned char img2_viewmpeg2[] = {
/*
- * Constructs a ViewMPEG2 as a child of 'tqparent', with the
+ * Constructs a ViewMPEG2 as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/